package com.tfis.system.service.impl;

import java.util.List;
import com.tfis.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.tfis.system.mapper.AircraftSystemMapper;
import com.tfis.system.domain.AircraftSystem;
import com.tfis.system.service.IAircraftSystemService;

/**
 * 系统信息管理Service业务层处理
 * 
 * @author allen
 * @date 2023-11-23
 */
@Service
public class AircraftSystemServiceImpl implements IAircraftSystemService 
{
    @Autowired
    private AircraftSystemMapper aircraftSystemMapper;

    /**
     * 查询系统信息管理
     * 
     * @param id 系统信息管理主键
     * @return 系统信息管理
     */
    @Override
    public AircraftSystem selectAircraftSystemById(Long id)
    {
        return aircraftSystemMapper.selectAircraftSystemById(id);
    }

    /**
     * 查询系统信息管理列表
     * 
     * @param aircraftSystem 系统信息管理
     * @return 系统信息管理
     */
    @Override
    public List<AircraftSystem> selectAircraftSystemList(AircraftSystem aircraftSystem)
    {
        return aircraftSystemMapper.selectAircraftSystemList(aircraftSystem);
    }

    /**
     * 新增系统信息管理
     * 
     * @param aircraftSystem 系统信息管理
     * @return 结果
     */
    @Override
    public int insertAircraftSystem(AircraftSystem aircraftSystem)
    {
        aircraftSystem.setCreateTime(DateUtils.getNowDate());
        return aircraftSystemMapper.insertAircraftSystem(aircraftSystem);
    }

    /**
     * 修改系统信息管理
     * 
     * @param aircraftSystem 系统信息管理
     * @return 结果
     */
    @Override
    public int updateAircraftSystem(AircraftSystem aircraftSystem)
    {
        aircraftSystem.setUpdateTime(DateUtils.getNowDate());
        return aircraftSystemMapper.updateAircraftSystem(aircraftSystem);
    }

    /**
     * 批量删除系统信息管理
     * 
     * @param ids 需要删除的系统信息管理主键
     * @return 结果
     */
    @Override
    public int deleteAircraftSystemByIds(Long[] ids)
    {
        return aircraftSystemMapper.deleteAircraftSystemByIds(ids);
    }

    /**
     * 删除系统信息管理信息
     * 
     * @param id 系统信息管理主键
     * @return 结果
     */
    @Override
    public int deleteAircraftSystemById(Long id)
    {
        return aircraftSystemMapper.deleteAircraftSystemById(id);
    }
}
